@@ -4,14 +4,14 @@ class Reader:
     """Get updates on the feeds supplied"""
 
     def __init__(self, feeds, silent=False):
-        self.feeds = {}
+        self.feeds = []
         self.silent = silent
         for feed in feeds:
             f = feedparser.parse(feeds[feed])
             if f.bozo:
                 self.output('WARNING: could not parse feed {}'.format(feed))
             else:
-                self.feeds[feed] = f
+                self.feeds.append(f)
 
     def output(self, arg):
         if not self.silent:
